#######################################################
#######################################################
############    COPYRIGHT - DATA SOCIETY   ############
#######################################################
#######################################################

###############################
##   PLOTTING WITH GGPLOT2   ##
###############################

## NOTE: To run individual pieces of code 
## select the line of code and press ctrl + enter for Windows
## and command + enter for Macs

#==================================================================================

# Ggplot2 is a versatile and powerful package for visualization!

# 1. Install and load ggplot2.

# Install the ggplot2 package
install.packages("ggplot2")

# Loading the library ggplot2
library(ggplot2)

# 2. Read in the CaBi.annual.csv and view the file.

# Reading in files, windows uses the C:/ directory, Mac uses the ~Desktop directory
setwd("path to files")
CaBi.annual = read.csv("CaBi.annual.csv")

# View the file
View(CaBi.annual)

# 3. What are the categories in the data set?

names(CaBi.annual)

# [1] "Municipality"     "Year"             "Month"            "No.Months"        "No.Stations"     
# [6] "New.Member.Count" "Total"    

# 4. Create a scatterplot that plots the number of stations on the x axis
#    and the total membership on the y axis.

ggplot(CaBi.annual, 
       aes(x = No.Stations, 
           y = Total)) + 
  geom_point()

# 5. Subset the second through seventh columns and label it CaBi.combined.

CaBi.combined = subset(CaBi.annual[,2:7])
View(CaBi.combined)


# 6. Use ddply to combine the number of new members by month and label the 
#    data as CaBi.sum.

install.packages("plyr")
library(plyr)

CaBi.sum = ddply(CaBi.combined, .(No.Months), summarise,
                 "New.Members" = sum(New.Member.Count))
View(CaBi.sum)

# 7. Isolate columns 1, 2 and 4 from CaBi.combined and label the data sets
#    CaBi.combined_2.

CaBi.combined_2 = CaBi.combined[,c(1, 2, 4)] 
View(CaBi.combined_2)

# 8. Combine the rows that are identical with the unique() function
#    and label it CaBi.combined_3.

CaBi.combined_3 = unique(CaBi.combined_2)
View(CaBi.combined_3)


# 9. Combine CaBi.combined_3 and CaBi.sum and label the new set
#    CaBi.month.

CaBi.month = cbind(CaBi.combined_3, CaBi.sum)
View(CaBi.month)

# 10. Graph a scatterplot with a line - assign No.Months to the x axis
#     and New.Members to the y axis.

ggplot(CaBi.month, 
       aes(x = No.Months, 
           y = New.Members)) + 
  geom_point() +
  geom_line()

# 11. Visualize the same data as 10, but with a bar plot.

ggplot(CaBi.month, 
       aes(x = No.Months, 
           y = New.Members)) + 
  geom_bar(stat = "identity")

# 12. Graph the number of months against the number of stations
#     as a bubble plot, with the size corresponding to the New.Members
#     from the CaBi.month data.

ggplot(CaBi.month, aes(x = No.Months, 
                   y = No.Stations, 
                   size = New.Members)) + 
  geom_point()

# 13. Add color to the bubble plot from Question 12.

ggplot(CaBi.month, aes(x = No.Months, 
                       y = No.Stations, 
                       size = New.Members,
                       color = New.Members)) + 
  geom_point()

# 14. Which way do you think is the best way to visualize this data and 
#     why?

# Answers may vary

# The bar plot looks the be the most intuitive and clear way to visualize
# this data, although arguments can be made for other graphs based on
# the purpose. 


# Continue to practice these operations until you feel
# comfortable in R. The only way to become truly
# proficient is to spend time coding!